@@ -51,6 +51,11 @@ void callback(DBusPendingCall* call, void* /*data*/)
 
 StatusHildon::StatusHildon()
 {
+  if (GetDBusConnection()==NULL) {
+    std::cerr << "No DBus connection!" << std::endl;
+    return;
+  }
+
   dbus_connection_add_filter(GetDBusConnection(),DBusMsgHandler,this,NULL);
 }
 
@@ -291,6 +296,11 @@ bool StatusHildon::UpdateNetworks()
 
   std::cout << "Requesting network scan..." << std::endl;
 
+  if (GetDBusConnection()==NULL) {
+    std::cerr << "No DBus connection!" << std::endl;
+    return false;
+  }
+
   msg=dbus_message_new_method_call("com.nokia.wlancond",
                                    "/com/nokia/wlancond/request",
                                    "com.nokia.wlancond.request",
@@ -330,6 +340,11 @@ bool StatusHildon::SetPowerSaving(bool savePower)
   dbus_bool_t     powerModeActivated = savePower ? TRUE : FALSE;
   bool            result;
 
+  if (GetDBusConnection()==NULL) {
+    std::cerr << "No DBus connection!" << std::endl;
+    return false;
+  }
+
   msg=dbus_message_new_method_call("com.nokia.wlancond",
                                    "/com/nokia/wlancond/request",
                                    "com.nokia.wlancond.request",
