@@ -181,6 +181,7 @@ private:
     StatusNone             status;
 #endif
 
+  Lum::Audio::PlaySound    *scanNetworkSound;
   Lum::Audio::PlaySound    *openNetworkSound;
 
 private:
@@ -240,6 +241,10 @@ private:
     CancelNetworks();
 
     if (status.SupportsNetworkRetrieval()) {
+      if (scanNetworkSound!=NULL) {
+        std::cout << "*** Playing scan sound..." << std::endl;
+        scanNetworkSound->Play();
+      }
       if (status.UpdateNetworks()) {
         Lum::OS::display->AddTimer(NETWORK_REFRESH+POLL_ERROR_TIMEOUT,0,networksErrorTimer);
       }
@@ -451,6 +456,7 @@ public:
     networksErrorTimer(new Lum::Model::Action()),
     configAction(new Lum::Model::Action()),
     aboutAction(new Lum::Model::Action()),
+    scanNetworkSound(NULL),
     openNetworkSound(NULL)
   {
     quality->SetRange(0,100);
@@ -476,31 +482,55 @@ public:
     Observe(status.statusChangedAction);
     Observe(status.networksChangedAction);
 
-    Lum::Base::Path soundPath;
+    Lum::Base::Path openNetworkSoundPath;
 
-    soundPath.SetNativeDir(Lum::Base::Path::GetCWD());
-    soundPath.AppendDir(L"data");
-    soundPath.AppendDir(L"sounds");
-    soundPath.SetBaseName(L"opennetwork.wav");
+    openNetworkSoundPath.SetNativeDir(Lum::Base::Path::GetCWD());
+    openNetworkSoundPath.AppendDir(L"data");
+    openNetworkSoundPath.AppendDir(L"sounds");
+    openNetworkSoundPath.SetBaseName(L"opennetwork.wav");
 
 #if defined(APP_DATADIR)
-    if (!soundPath.Exists()) {
-      soundPath.SetNativeDir(Lum::Base::StringToWString(APP_DATADIR));
-      soundPath.AppendDir(L"sounds");
-      soundPath.SetBaseName(L"opennetwork.wav");
+    if (!openNetworkSoundPath.Exists()) {
+      openNetworkSoundPath.SetNativeDir(Lum::Base::StringToWString(APP_DATADIR));
+      openNetworkSoundPath.AppendDir(L"sounds");
+      openNetworkSoundPath.SetBaseName(L"opennetwork.wav");
     }
 #endif
 
-    if (soundPath.Exists()) {
+    if (openNetworkSoundPath.Exists()) {
       openNetworkSound=Lum::Audio::GetPlaySound();
       if (openNetworkSound!=NULL) {
-        openNetworkSound->SetFilename(soundPath.GetPath(),Lum::Audio::PlaySound::typeWav);
+        openNetworkSound->SetFilename(openNetworkSoundPath.GetPath(),Lum::Audio::PlaySound::typeWav);
+      }
+    }
+
+    Lum::Base::Path scanNetworkSoundPath;
+
+    scanNetworkSoundPath.SetNativeDir(Lum::Base::Path::GetCWD());
+    scanNetworkSoundPath.AppendDir(L"data");
+    scanNetworkSoundPath.AppendDir(L"sounds");
+    scanNetworkSoundPath.SetBaseName(L"scannetwork.wav");
+
+#if defined(APP_DATADIR)
+    if (!scanNetworkSoundPath.Exists()) {
+      scanNetworkSoundPath.SetNativeDir(Lum::Base::StringToWString(APP_DATADIR));
+      scanNetworkSoundPath.AppendDir(L"sounds");
+      scanNetworkSoundPath.SetBaseName(L"scannetwork.wav");
+    }
+#endif
+
+
+    if (scanNetworkSoundPath.Exists()) {
+      scanNetworkSound=Lum::Audio::GetPlaySound();
+      if (scanNetworkSound!=NULL) {
+        scanNetworkSound->SetFilename(scanNetworkSoundPath.GetPath(),Lum::Audio::PlaySound::typeWav);
       }
     }
   }
 
   ~MyWindow()
   {
+    delete scanNetworkSound;
     delete openNetworkSound;
   }
 
